@@ -1,6 +1,9 @@
 package Dist::Zilla::PluginBundle::AVAR;
 BEGIN {
-  $Dist::Zilla::PluginBundle::AVAR::VERSION = '0.18';
+  $Dist::Zilla::PluginBundle::AVAR::AUTHORITY = 'cpan:AVAR';
+}
+BEGIN {
+  $Dist::Zilla::PluginBundle::AVAR::VERSION = '0.19';
 }
 
 use 5.10.0;
@@ -16,6 +19,7 @@ use Dist::Zilla::Plugin::MetaNoIndex;
 use Dist::Zilla::Plugin::ReadmeFromPod;
 use Dist::Zilla::Plugin::MakeMaker::Awesome;
 use Dist::Zilla::Plugin::CompileTests;
+use Dist::Zilla::Plugin::Authority;
 
 sub bundle_config {
     my ($self, $section) = @_;
@@ -28,21 +32,33 @@ sub bundle_config {
     my $use_mm      = $args->{use_MakeMaker} // 1;
     my $use_ct      = $args->{use_CompileTests} // 1;
     my $bugtracker  = $args->{bugtracker}  // 'rt';
+    die "AVAR: Don't use GitHub as a tracker" if $bugtracker eq 'github';
     my $homepage    = $args->{homepage};
-    my $repository  = $args->{repository};
-    my $tracker;
+    die "AVAR: Upgrade to new format" if $args->{repository};
+    my $repository_url  = $args->{repository_url};
+    my $repository_web  = $args->{repository_web};
+    my ($tracker, $tracker_mailto);
     my $page;
-    my $repo;
+    my ($repo_url, $repo_web);
 
     given ($bugtracker) {
         when ('github') { $tracker = "http://github.com/$github_user/$ldist/issues" }
-        when ('rt')     { $tracker = "https://rt.cpan.org/Public/Dist/Display.html?Name=$dist" }
+        when ('rt')     {
+            $tracker = "https://rt.cpan.org/Public/Dist/Display.html?Name=$dist";
+            $tracker_mailto = sprintf 'bug-%s@rt.cpan.org', $dist;
+        }
         default         { $tracker = $bugtracker }
     }
 
-    given ($repository) {
-        when (not defined) { $repo = "http://github.com/$github_user/$ldist" }
-        default            { $repo = $repository }
+    given ($repository_url) {
+        when (not defined) {
+            $repo_web = "http://github.com/$github_user/$ldist";
+            $repo_url = "git://github.com/$github_user/$ldist.git";
+        }
+        default {
+            $repo_web = $repository_web;
+            $repo_url = $repository_url;
+        }
     }
 
     given ($homepage) {
@@ -84,13 +100,22 @@ sub bundle_config {
         [
             MetaResources => {
                 homepage => $page,
-                bugtracker => $tracker,
-                repository => $repo,
+                'bugtracker.url' => $tracker,
+                'bugtracker.mailto' => $tracker_mailto,
+                'repository.type' => 'git',
+                'repository.url' => $repo_url,
+                'repository.web' => $repo_web,
                 license => 'http://dev.perl.org/licenses/',
                 Ratings => "http://cpanratings.perl.org/d/$dist",
             }
 
         ],
+        [
+            Authority => {
+                authority   => 'cpan:AVAR',
+                do_metadata => 1,
+            }
+        ],
         # Bump the Changlog
         [
             NextRelease => {
@@ -171,10 +196,17 @@ It's equivalent to:
     [MetaResources]
     ;; $github_user is 'avar' by default, $lc_dist is lc($dist)
     homepage   = http://search.cpan.org/dist/$dist/
-    bugtracker = http://github.com/$github_user/$lc_dist/issues
-    repository = http://github.com/$github_user/$lc_dist
+    bugtracker.mailto = bug-$dist@rt.cpan.org
+    bugtracker.web = https://rt.cpan.org/Public/Dist/Display.html?Name=$dist
+    repository.web = http://github.com/$github_user/$lc_dist
+    repository.url = git://github.com/$github_user/$lc_dist.git
+    repository.type = git
     license    = http://dev.perl.org/licenses/
     Ratings    = http://cpanratings.perl.org/d/$dist
+
+    [Authority]
+    authority   = cpan:AVAR
+    do_metadata = 1
     
     [NextRelease]
     format = %-2v %{yyyy-MM-dd HH:mm:ss}d
